@@ -1,6 +1,6 @@
 /* 
-logpp (Log PreProcessor) 0.14 - logpp.h
-Copyright (C) 2006-2007 Risto Vaarandi
+logpp (Log PreProcessor) 0.15 - logpp.h
+Copyright (C) 2006-2008 Risto Vaarandi
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #define REPLACENULL '_' /* replace null bytes with _ in log lines */
 #define COMMENT '#'     /* comments in config files begin with # */
 #define MATCHVAR '$'    /* match variables in templates begin with $ */
+#define IFILEVAR '~'    /* the ~ variable denotes an input file name */
 #define MVARBUFSIZE 100 /* match variable buffer size (equals to max 
                            number of ()-constructs in regexps plus 1) */
 #define SHELL "/bin/sh" /* shell for parsing forked command lines */
@@ -62,7 +63,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 /* template_elem defines a part of a template where either 'str' is a string
    and 'len' is its length, or 'num' is a backreference variable number and
-   'str' is NULL. 
+   'str' is NULL ('num' can be negative, e.g., -1 denotes an input file name).
    For example, "Message $1 received" will be split into the following parts: 
    "Message ", 1, " received"
 */
@@ -70,7 +71,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 struct template_elem {
   char *str;
   size_t len;
-  size_t num;
+  ssize_t num;
 };
 
 /* cond defines a filter condition where:
