@@ -1,6 +1,6 @@
 /* 
-logpp (Log PreProcessor) 0.14 - process.c
-Copyright (C) 2006-2007 Risto Vaarandi
+logpp (Log PreProcessor) 0.15 - process.c
+Copyright (C) 2006-2008 Risto Vaarandi
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -31,8 +31,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 ssize_t
 match_data(struct src *file, struct cond *cond, char *line, size_t size)
 {
-  size_t i, num, len, len2, count; 
-  ssize_t start, end;
+  size_t i, len, len2, count; 
+  ssize_t num, start, end;
   char *matchbuf;
   char regmatch;
 #ifdef HAVE_LIBPCRE
@@ -110,8 +110,20 @@ match_data(struct src *file, struct cond *cond, char *line, size_t size)
     /* the template part is a match variable */
     if (!cond->template[i].str) {
       num = cond->template[i].num;
+      /* if the variable is $~, add input file name to 'line' */
+      if (num == -1) {
+        len2 = strlen(file->name);
+        if (count + len2 < size) {
+          memcpy(line + count, file->name, len2);
+          count += len2;
+        } else {
+          memcpy(line + count, file->name, size - count - 1);
+          count = size - 1;
+          break;
+        }
+      }
       /* if the variable is $0, add all bytes from 'matchbuf' to 'line' */
-      if (!num) {
+      else if (num == 0) {
         if (count + len < size) {
           memcpy(line + count, matchbuf, len);
           count += len;
