@@ -1,6 +1,6 @@
 /* 
-logpp (Log PreProcessor) 0.14 - readconf.c
-Copyright (C) 2006-2007 Risto Vaarandi
+logpp (Log PreProcessor) 0.15 - readconf.c
+Copyright (C) 2006-2008 Risto Vaarandi
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -372,30 +372,38 @@ parse_filter(struct keyval *rec, char *name, char *filename)
           template[num].len = len;
           ++num;
         }
-        /* convert characters after MATCHVAR to a number and store it */
-        st = end + 1;
-        convbuf = strtol(st, &end, 10);
-        /* if the conversion failed (the string begins with a non-digit
-           that strtol would pass like '+' or whitespace, or the result is 
-           out of range), store MATCHVAR as a 1-char string and continue 
-           the processing from the next character ('st') */
-        if (!isdigit((int) *st) || 
-            convbuf < 0 || convbuf > MVARBUFSIZE - 1) {
-          if (isdigit((int) *st))
-            log_msg(LOG_ERR, 
-                    "%s: Match variable $%ld out of range 0..%d in filter %s", 
-                    filename, convbuf, MVARBUFSIZE - 1, name);
-          template[num].str = (char *) my_malloc(sizeof(char) * 2);
-          template[num].str[0] = MATCHVAR;
-          template[num].str[1] = 0;
-          template[num].len = 1;
-        }
-        /* if the conversion was successful, save the number and jump
-           to the next character after the number ('end') */
-        else {
-          template[num].num = convbuf;
+        /* if MATCHVAR is followed by IFILEVAR, set variable number to -1
+           and continue with the character after IFILEVAR ('end' + 2); 
+           otherwise convert characters after MATCHVAR to variable number */
+        if (*(end + 1) == IFILEVAR) {
+          template[num].num = -1;
           template[num].str = 0;
-          st = end;
+          st = end + 2;
+        } else {
+          st = end + 1;
+          convbuf = strtol(st, &end, 10);
+          /* if the conversion failed (the string begins with a non-digit
+             that strtol would pass like '+' or whitespace, or the result is 
+             out of range), store MATCHVAR as a 1-char string and continue 
+             the processing from the next character ('st') */
+          if (!isdigit((int) *st) || 
+              convbuf < 0 || convbuf > MVARBUFSIZE - 1) {
+            if (isdigit((int) *st))
+              log_msg(LOG_ERR, 
+                      "%s: Match variable $%ld out of range 0..%d in filter %s", 
+                      filename, convbuf, MVARBUFSIZE - 1, name);
+            template[num].str = (char *) my_malloc(sizeof(char) * 2);
+            template[num].str[0] = MATCHVAR;
+            template[num].str[1] = 0;
+            template[num].len = 1;
+          }
+          /* if the conversion was successful, save the number and jump
+             to the next character after the number ('end') */
+          else {
+            template[num].num = convbuf;
+            template[num].str = 0;
+            st = end;
+          }
         }
         ++num;
       }
